@@ -332,6 +332,15 @@ using the configure script.
 
 #endif
 
+#if 0
+#define NTL_DISABLE_LL_ASM
+
+/* Explicitly disables us of inline assembly as a replacement
+ * for long lobg arithmetic.
+ */
+
+#endif
+
 
 #if 0
 #define NTL_MAXIMIZE_SP_NBITS
@@ -441,7 +450,7 @@ using the configure script.
  * FFT modulo single-precision primes is implemented.
  */
 
-#if 1
+#if 0
 #define NTL_FFT_BIGTAB
 
 /*
@@ -620,6 +629,4 @@ using the configure script.
 
 
 
-
-
 #endif
